from distutils.core import setup

setup(
    name = 'trade_order',      
    version = '1.1.0',
    py_modules = ['trade_order'],
    author = 'easyQuant',        
    author_email = '532894539@qq.com',
    url = 'https://github.com/easyQuant/trade_order',
    description = 'python版本的 A股实盘交易接口'
)